@@ -5,5 +5,5 @@ class LookupGroup(models.Model):
     name = models.CharField(max_length=255)
     lookup_id = models.CharField(max_length=255, unique=True)
 
-    def __unicode__(self):
+    def __str__(self):
         return "%s (%s)" % (self.name, self.lookup_id)
\ No newline at end of file
